
## CATO-CLI - query.site.cloudInterconnectConnectionConnectivity:
[Click here](https://api.catonetworks.com/documentation/#query-query.site.cloudInterconnectConnectionConnectivity) for documentation on this operation.

### Usage for query.site.cloudInterconnectConnectionConnectivity:

```bash
catocli query site cloudInterconnectConnectionConnectivity -h

catocli query site cloudInterconnectConnectionConnectivity <json>

catocli query site cloudInterconnectConnectionConnectivity --json-file query.site.cloudInterconnectConnectionConnectivity.json

catocli query site cloudInterconnectConnectionConnectivity '{"cloudInterconnectConnectionConnectivityInput":{"id":"id"}}'

catocli query site cloudInterconnectConnectionConnectivity '{
    "cloudInterconnectConnectionConnectivityInput": {
        "id": "id"
    }
}'
```

#### Operation Arguments for query.site.cloudInterconnectConnectionConnectivity ####

`accountId` [ID] - (required) N/A    
`cloudInterconnectConnectionConnectivityInput` [CloudInterconnectConnectionConnectivityInput] - (required) N/A    
